# DetailedExtensions

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**topic_labels** | [**list[Label]**](Label.md) |  | [optional] 
**topic_types** | [**list[TopicType]**](TopicType.md) |  | [optional] 
**topic_statuses** | [**list[TopicStatus]**](TopicStatus.md) |  | [optional] 
**priorities** | [**list[Priority]**](Priority.md) |  | [optional] 
**stages** | [**list[Stage]**](Stage.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


